pub enum FileStreamItem {
Metadata(FileMetadata),
Template(RequestTemplateInput),
Abort,
Error(String),
}Expand description
Items that can be yielded from a file upload stream
Variants
Metadata(FileMetadata)
File metadata (should be first item in stream)
Template(RequestTemplateInput)
A request template parsed from JSONL
Abort
Producer is aborting the stream. Fusillade should rollback and stop processing.
Error(String)
👎Deprecated:
Use FileStreamItem::Abort and retain the producer error locally instead
Deprecated compatibility path for callers that still surface producer parse errors here.