pub struct BatchStatus {
pub batch_id: BatchId,
pub file_id: Option<FileId>,
pub file_name: Option<String>,
pub total_requests: i64,
pub pending_requests: i64,
pub in_progress_requests: i64,
pub completed_requests: i64,
pub failed_requests: i64,
pub canceled_requests: i64,
pub started_at: Option<DateTime<Utc>>,
pub failed_at: Option<DateTime<Utc>>,
pub created_at: DateTime<Utc>,
}Expand description
Status information for a batch, computed from its executions.
Fields
batch_id: BatchIdfile_id: Option<FileId>file_name: Option<String>total_requests: i64pending_requests: i64in_progress_requests: i64completed_requests: i64failed_requests: i64canceled_requests: i64started_at: Option<DateTime<Utc>>failed_at: Option<DateTime<Utc>>created_at: DateTime<Utc>Implementations
Sourceimpl BatchStatus
impl BatchStatus
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Check if the batch has finished (all requests in terminal state).
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Check if the batch is still running.
Sourcepub fn openai_status(&self) -> &'static str
pub fn openai_status(&self) -> &'static str
Get OpenAI-compatible status string. Maps internal state to OpenAI’s status values:
- “validating” - batch just created, no requests started yet
- “in_progress” - batch is being processed
- “finalizing” - nearly all requests done (95%+ complete)
- “completed” - all requests in terminal state and at least one succeeded
- “failed” - all requests in terminal state and all failed
- “cancelled” - all requests cancelled