Module manager

Module manager 

Main traits for the batching system.

This module defines the Storage and RequestManager traits, which provide the interface for persisting requests, creating files, launching batches, and checking execution status.

Structs

ModelFilter
A single model_filters event describing a model’s internal-liveness transition.

Enums

ModelFilterState
Liveness state of a model on internal (self-hosted) infrastructure, as published by the controller into the model_filters append-only event log.

Traits

DaemonStorage
Daemon lifecycle persistence.
Storage
Storage trait for persisting and querying requests.