Helper functions for serializing and deserializing errors to/from JSON.
These are used to store error information in the database in a structured format. TODO: What’s the point of this module? Thisi s just serde logic right? Why can’t we just use serde_json
Structs
- Serialized
Error - Serialized error format that preserves error message and source chain.
Functions
- deserialize_
error - Deserializes an error from a JSON string.
- serialize_
error - Serializes an anyhow::Error to a JSON string.